/*
    Copyright (C) 2008-2022, Millistream Market Data <support@millistream.com>

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.

*/

#ifndef MDF_FIELDS
#define MDF_FIELDS 1

/* values for the MDF_F_TRADECODE field, these values form
 * a bit-field so the values can be OR:ed together */
#define MDF_TC_OFFHOURS       1
#define MDF_TC_OUTSIDESPREAD  2
#define MDF_TC_REPORTED       4
#define MDF_TC_CORRECTION     8
#define MDF_TC_CANCEL        16
#define MDF_TC_UPDATEHIGHLOW 32
#define MDF_TC_UPDATEVOLUME  64
#define MDF_TC_UPDATELAST   128
#define MDF_TC_ODDLOT       256
#define MDF_TC_DELAYED      512
#define MDF_TC_DARKPOOL    1024

/* Message References */
#define MDF_M_MESSAGESREFERENCE  0
#define MDF_M_LOGON              1
#define MDF_M_LOGOFF             2
#define MDF_M_LOGONGREETING      3
#define MDF_M_NEWSHEADLINE       4
#define MDF_M_QUOTE              5
#define MDF_M_TRADE              6
#define MDF_M_BIDLEVELINSERT     7
#define MDF_M_ASKLEVELINSERT     8
#define MDF_M_BIDLEVELDELETE     9
#define MDF_M_ASKLEVELDELETE    10
#define MDF_M_BIDLEVELUPDATE    11
#define MDF_M_ASKLEVELUPDATE    12
#define MDF_M_INSTRUMENTRESET   13
#define MDF_M_ORDERBOOKFLUSH    14
#define MDF_M_BASICDATA         15
#define MDF_M_PRICEHISTORY      16
#define MDF_M_INSTRUMENTDELETE  17
#define MDF_M_FIELDSREFERENCE   18
#define MDF_M_REQUEST           19
#define MDF_M_REQUESTFINISHED   20
#define MDF_M_INSREF            21
#define MDF_M_NEWSCONTENT       22
#define MDF_M_CORPORATEACTION   23
#define MDF_M_TRADESTATE        24
#define MDF_M_FUNDAMENTALS      25
#define MDF_M_PERFORMANCE       26
#define MDF_M_KEYRATIOS         27
#define MDF_M_ESTIMATES         28
#define MDF_M_ESTIMATESHISTORY  29
#define MDF_M_NETORDERIMBALANCE 30
#define MDF_M_UNSUBSCRIBE       31
#define MDF_M_L10N              32
#define MDF_M_CI                33
#define MDF_M_CIHISTORY         34
#define MDF_M_PRIIP             35
#define MDF_M_MIFID             36
#define MDF_M_MIFIDHISTORY      37
#define MDF_M_MAPPINGS          38
#define MDF_M_MBOADD            39
#define MDF_M_MBOUPDATE         40
#define MDF_M_MBODELETE         41
#define MDF_M_GREEKS            42
#define MDF_M_QUOTEBBO          43
#define MDF_M_QUOTEEX           44

/* Message Classes, these values can be OR:ed together */
#define MDF_MC_UNDEF                 0U
#define MDF_MC_NEWSHEADLINE          1U
#define MDF_MC_QUOTE                 2U
#define MDF_MC_TRADE                 4U
#define MDF_MC_ORDER                 8U
#define MDF_MC_BASICDATA            16U
#define MDF_MC_PRICEHISTORY         32U
#define MDF_MC_NEWSCONTENT          64U
#define MDF_MC_CORPORATEACTION     128U
#define MDF_MC_TRADESTATE          256U
#define MDF_MC_FUNDAMENTALS        512U
#define MDF_MC_PERFORMANCE        1024U
#define MDF_MC_KEYRATIOS          2048U
#define MDF_MC_ESTIMATES          4096U
#define MDF_MC_ESTIMATESHISTORY   8192U
#define MDF_MC_NETORDERIMBALANCE 16384U
#define MDF_MC_L10N              32768U
#define MDF_MC_CI                65536U
#define MDF_MC_CIHISTORY        131072U
#define MDF_MC_PRIIP            262144U
#define MDF_MC_MIFID            524288U
#define MDF_MC_MIFIDHISTORY    1048576U
#define MDF_MC_MAPPINGS        2097152U
#define MDF_MC_MBO             4194304U
#define MDF_MC_GREEKS          8388608U
#define MDF_MC_QUOTEBBO       16777216U
#define MDF_MC_QUOTEEX        33554432U

/* Request Classes, use these when issuing requests to
 * the server/system. They are defined as strings to
 * make them easier to use in mdf_message_add_numeric()
 * and mdf_message_add_list() */
#define MDF_RC_NEWSHEADLINE      "0"
#define MDF_RC_QUOTE             "1"
#define MDF_RC_TRADE             "2"
#define MDF_RC_ORDER             "3"
#define MDF_RC_BASICDATA         "4"
#define MDF_RC_PRICEHISTORY      "5"
#define MDF_RC_FIELDSREFERENCE   "6"
#define MDF_RC_INSREF            "7"
#define MDF_RC_NEWSCONTENT       "8"
#define MDF_RC_CORPORATEACTION   "9"
#define MDF_RC_TRADESTATE        "10"
#define MDF_RC_FUNDAMENTALS      "11"
#define MDF_RC_PERFORMANCE       "12"
#define MDF_RC_KEYRATIOS         "13"
#define MDF_RC_ESTIMATES         "14"
#define MDF_RC_ESTIMATESHISTORY  "15"
#define MDF_RC_NETORDERIMBALANCE "16"
#define MDF_RC_L10N              "17"
#define MDF_RC_CI                "18"
#define MDF_RC_CIHISTORY         "19"
#define MDF_RC_PRIIP             "20"
#define MDF_RC_MIFID             "21"
#define MDF_RC_MIFIDHISTORY      "22"
#define MDF_RC_MAPPINGS          "23"
#define MDF_RC_MBO               "24"
#define MDF_RC_GREEKS            "25"
#define MDF_RC_QUOTEBBO          "26"
#define MDF_RC_QUOTEEX           "27"

/* Request Types, again defined as strings for
 * easier use with mdf_message_add_numeric ().
 *
 * IMAGE is for requesting a snapshot of the current values
 * STREAM is for requesting streaming data
 * FULL is for requesting both IMAGE and STREAM
 *
 * When requesting MDF_RC_INSREF, this field is used to
 * tell the number of instrument references wanted. If
 * the number of requested references cannot be fulfilled,
 * for example due to account limits, the request will fail
 * in full */
#define MDF_RT_IMAGE  "1"
#define MDF_RT_STREAM "2"
#define MDF_RT_FULL   "3"

/* Corporate Action Types */
#define MDF_CA_DIVIDEND            "0"
#define MDF_CA_SPLIT               "1"
#define MDF_CA_RIGHTSISSUE         "2"
#define MDF_CA_BONUSISSUE          "3"
#define MDF_CA_DIRECTEDISSUE       "4"
#define MDF_CA_SHAREREDEMPTION     "5"
#define MDF_CA_SPINOFF             "6"
#define MDF_CA_STOCKDIVIDEND       "7"
#define MDF_CA_STOCKDIVIDENDEX     "8"
#define MDF_CA_UNKNOWN             "9"
#define MDF_CA_IPO                "10"
#define MDF_CA_CURRENCYCONVERSION "11"
#define MDF_CA_NOMINALVALUE       "12"
#define MDF_CA_CHANGEINUNDERLYING "13"
#define MDF_CA_CHANGEOFBASICDATA  "14"
#define MDF_CA_CALENDAR           "15"
#define MDF_CA_INSIDERTRADING     "16"
#define MDF_CA_SPLITANDREDEMPTION "17"
#define MDF_CA_EXCHANGECLOSED     "18"
#define MDF_CA_MAJORHOLDERS       "19"
#define MDF_CA_SHARELOAN          "20"

/* Fields/Tags */
#define MDF_F_LANGUAGE                0
#define MDF_F_HEADLINE                1
#define MDF_F_TEXTBODY                2
#define MDF_F_DATE                    3
#define MDF_F_TIME                    4
#define MDF_F_BIDPRICE                5
#define MDF_F_ASKPRICE                6
#define MDF_F_LASTPRICE               7
#define MDF_F_DAYHIGHPRICE            8
#define MDF_F_DAYLOWPRICE             9
#define MDF_F_QUANTITY               10
#define MDF_F_TURNOVER               11
#define MDF_F_TRADEPRICE             12
#define MDF_F_TRADEQUANTITY          13
#define MDF_F_TRADEREFERENCE         14
#define MDF_F_TRADECODE              15
#define MDF_F_ORDERLEVEL             16
#define MDF_F_NUMBIDORDERS           17
#define MDF_F_NUMASKORDERS           18
#define MDF_F_BIDQUANTITY            19
#define MDF_F_ASKQUANTITY            20
#define MDF_F_SYMBOL                 21
#define MDF_F_NAME                   22
#define MDF_F_ISIN                   23
#define MDF_F_BOARDLOT               24
#define MDF_F_INSTRUMENTTYPE         25
#define MDF_F_INSTRUMENTSUBTYPE      26
#define MDF_F_DERIVATIVEINDICATOR    27
#define MDF_F_EXERCISETYPE           28
#define MDF_F_ISSUECURRENCY          29
#define MDF_F_TRADECURRENCY          30
#define MDF_F_BASECURRENCY           31
#define MDF_F_QUOTECURRENCY          32
#define MDF_F_ISSUEDATE              33
#define MDF_F_STRIKEDATE             34
#define MDF_F_STRIKEPRICE            35
#define MDF_F_TRADETIME              36
#define MDF_F_NUMTRADES              37
#define MDF_F_EXECUTEDSIDE           38
#define MDF_F_OPENPRICE              39
#define MDF_F_CLOSEPRICE             40
#define MDF_F_CLOSEBIDPRICE          41
#define MDF_F_CLOSEASKPRICE          42
#define MDF_F_CLOSEDAYHIGHPRICE      43
#define MDF_F_CLOSEDAYLOWPRICE       44
#define MDF_F_CLOSEQUANTITY          45
#define MDF_F_CLOSETURNOVER          46
#define MDF_F_CLOSENUMTRADES         47
#define MDF_F_NEWSID                 48
#define MDF_F_REQUESTID              49
#define MDF_F_REQUESTSTATUS          50
#define MDF_F_REQUESTTYPE            51
#define MDF_F_REQUESTCLASS           52
#define MDF_F_INSREFLIST             53
#define MDF_F_MARKETPLACE            54
#define MDF_F_LIST                   55
#define MDF_F_INTERNALQUANTITY       56
#define MDF_F_INTERNALTURNOVER       57
#define MDF_F_CLOSEINTERNALQUANTITY  58
#define MDF_F_CLOSEINTERNALTURNOVER  59
#define MDF_F_TRADEBUYER             60
#define MDF_F_TRADESELLER            61
#define MDF_F_BIDCOUNTERPART         62
#define MDF_F_ASKCOUNTERPART         63
#define MDF_F_COMPANY                64
#define MDF_F_FUNDPPMCODE            65
#define MDF_F_UNDERLYINGID           66
#define MDF_F_USERNAME               67
#define MDF_F_PASSWORD               68
#define MDF_F_EXTRACREDENTIAL        69
#define MDF_F_LOGOFFREASON           70
#define MDF_F_TRADETYPE              71
#define MDF_F_TRADECANCELTIME        72
#define MDF_F_NEWSBLOCKNUMBER        73
#define MDF_F_BIDYIELD               74
#define MDF_F_ASKYIELD               75
#define MDF_F_LASTYIELD              76
#define MDF_F_OPENYIELD              77
#define MDF_F_DAYHIGHYIELD           78
#define MDF_F_DAYLOWYIELD            79
#define MDF_F_CLOSEBIDYIELD          80
#define MDF_F_CLOSEASKYIELD          81
#define MDF_F_CLOSEYIELD             82
#define MDF_F_CLOSEDAYHIGHYIELD      83
#define MDF_F_CLOSEDAYLOWYIELD       84
#define MDF_F_NEWSCODINGCOMPANY      85
#define MDF_F_NEWSCODINGTYPE         86
#define MDF_F_NEWSCODINGSUBJECT      87
#define MDF_F_NEWSCODINGCOUNTRY      88
#define MDF_F_NEWSCODINGORIGINAL     89
#define MDF_F_FUNDCOMPANY            90
#define MDF_F_FUNDPMICODE            91
#define MDF_F_COUNTRY                92
#define MDF_F_NAV                    93
#define MDF_F_CLOSENAV               94
#define MDF_F_TIS                    95
#define MDF_F_CLOSETIS               96
#define MDF_F_SOURCE                 97
#define MDF_F_S1                     98
#define MDF_F_CATYPE                 99
#define MDF_F_DIVIDEND              100
/* #define MDF_F_DIVIDENDORIGINAL      101 */
#define MDF_F_CASUBTYPE             102
#define MDF_F_ADJUSTMENTFACTOR      103
#define MDF_F_NUMBEROFSHARES        104
#define MDF_F_NUMBEROFSHARESDELTA   105
#define MDF_F_NEWSHARES             106
#define MDF_F_OLDSHARES             107
#define MDF_F_SUBSCRIPTIONPRICE     108
#define MDF_F_PERIOD                109
#define MDF_F_NOMINALVALUE          110
#define MDF_F_RECORDDATE            111
#define MDF_F_PAYMENTDATE           112
#define MDF_F_ANNOUNCEMENTDATE      113
#define MDF_F_TID                   114
#define MDF_F_NEWSISLASTBLOCK       115
#define MDF_F_SERVERNAME            116
#define MDF_F_SERVERTIME            117
#define MDF_F_SERVERDATE            118
#define MDF_F_MIC                   119
#define MDF_F_UNCHANGEDPAID         120
#define MDF_F_PLUSPAID              121
#define MDF_F_MINUSPAID             122
#define MDF_F_VWAP                  123
#define MDF_F_CLOSEVWAP             124
#define MDF_F_SPECIALCONDITION      125
#define MDF_F_TRADESTATE            126
#define MDF_F_SALES                 127
#define MDF_F_EBIT                  128
#define MDF_F_PRETAXPROFIT          129
#define MDF_F_NETPROFIT             130
#define MDF_F_EPS                   131
#define MDF_F_DILUTEDEPS            132
#define MDF_F_EBITDA                133
#define MDF_F_EBITA                 134
/* #define MDF_F_ORDERINTAKE           135
#define MDF_F_ORDERBACKLOG          136
#define MDF_F_NETINTERESTINCOME     137 */
#define MDF_F_NETFININCOME          138
/* #define MDF_F_NETFEEANDCOMINCOME    139
#define MDF_F_TOPERATINGEXPENSES    140
#define MDF_F_TOPERATINGINCOME      141
#define MDF_F_PROFITBEFOREWACL      142
#define MDF_F_CREDITLOSS            143
#define MDF_F_RENTALINCOME          144
#define MDF_F_PROPERTYMGMTRESULT    145
#define MDF_F_REALIZEDCHGPROP       146
#define MDF_F_UNREALIZEDCHGPROP     147 */
#define MDF_F_CLOSEPRICE1D          148
#define MDF_F_CLOSEPRICE1W          149
#define MDF_F_CLOSEPRICE1M          150
#define MDF_F_CLOSEPRICE3M          151
#define MDF_F_CLOSEPRICE6M          152
#define MDF_F_CLOSEPRICE9M          153
#define MDF_F_CLOSEPRICE1Y          154
#define MDF_F_CLOSEPRICE2Y          155
#define MDF_F_CLOSEPRICE5Y          156
#define MDF_F_CLOSEPRICE10Y         157
#define MDF_F_CLOSEPRICEWTD         158
#define MDF_F_CLOSEPRICEMTD         159
#define MDF_F_CLOSEPRICEQTD         160
#define MDF_F_CLOSEPRICEYTD         161
#define MDF_F_CLOSEPRICEPYTD        162
#define MDF_F_ATH                   163
#define MDF_F_ATL                   164
#define MDF_F_HIGHPRICE1Y           165
#define MDF_F_LOWPRICE1Y            166
#define MDF_F_NEWSCODINGISIN        167
#define MDF_F_CHAIRMAN              168
#define MDF_F_CEO                   169
#define MDF_F_WEBSITE               170
#define MDF_F_ORGNUM                171
#define MDF_F_DESCRIPTION           172
#define MDF_F_EQUITYRATIO           173
/* #define MDF_F_RETURNONEQUITY        174 */
#define MDF_F_DIVIDENDYIELD         175
#define MDF_F_PER                   176
#define MDF_F_PSR                   177
#define MDF_F_S2                    179
#define MDF_F_S3                    180
#define MDF_F_S4                    181
#define MDF_F_S5                    182
#define MDF_F_ATHDATE               183
#define MDF_F_ATLDATE               184
#define MDF_F_HIGHPRICE1YDATE       185
#define MDF_F_LOWPRICE1YDATE        186
#define MDF_F_REDEMPTIONPRICE       187
#define MDF_F_SECTOR                188
#define MDF_F_OPERATINGCASHFLOW     189
/* #define MDF_F_ADJUSTEDEQUITY        190 */
#define MDF_F_PRICETOCASHFLOW       191
#define MDF_F_PRICETOADJUSTEDEQUITY 192
#define MDF_F_HIGHPRICEYTD          193
#define MDF_F_LOWPRICEYTD           194
#define MDF_F_HIGHPRICEYTDDATE      195
#define MDF_F_LOWPRICEYTDDATE       196
#define MDF_F_COUNT                 197
#define MDF_F_GROSSPROFIT           198
#define MDF_F_NETSALES              199
#define MDF_F_ADJUSTEDEBITA         200
#define MDF_F_TRADEYIELD            201
#define MDF_F_VOTINGPOWERPRC        202
#define MDF_F_CAPITALPRC            203
#define MDF_F_GENDERCEO             204
#define MDF_F_GENDERCHAIRMAN        205
#define MDF_F_BIRTHYEARCEO          206
#define MDF_F_BIRTHYEARCHAIRMAN     207
#define MDF_F_ADDRESS               208
#define MDF_F_POSTALCODE            209
#define MDF_F_CITY                  210
#define MDF_F_TELEPHONE             211
#define MDF_F_FAX                   212
#define MDF_F_EMAIL                 213
#define MDF_F_IMPORTANTEVENTS       214
#define MDF_F_INTANGIBLEASSET       215
#define MDF_F_GOODWILL              216
#define MDF_F_FIXEDASSET            217
#define MDF_F_FINANCIALASSET        218
#define MDF_F_NONCURRENTASSET       219
#define MDF_F_INVENTORY             220
#define MDF_F_OTHERCURRENTASSET     221
#define MDF_F_ACCOUNTSRECEIVABLE    222
#define MDF_F_OTHERRECEIVABLES      223
#define MDF_F_SHORTTERMINV          224
#define MDF_F_CCE                   225
#define MDF_F_CURRENTASSETS         226
#define MDF_F_TOTALASSETS           227
#define MDF_F_SHEQUITY              228
#define MDF_F_MINORITYINTEREST      229
#define MDF_F_PROVISIONS            230
#define MDF_F_LTLIABILITIES         231
#define MDF_F_CURLIABILITIES        232
#define MDF_F_TOTSHEQLIABILITIES    233
#define MDF_F_NIBL                  234
/* #define MDF_F_TOTLIABILITIES        235 */
#define MDF_F_IBL                   236
#define MDF_F_CASHFLOWBWC           237
#define MDF_F_CASHFLOWAWC           238
#define MDF_F_CASHFLOWIA            239
#define MDF_F_CASHFLOWFA            240
#define MDF_F_CASHFLOWTOTAL         241
#define MDF_F_NUMEMPLOYEES          242
#define MDF_F_MCAP                  243
#define MDF_F_CONTRACTSIZE          244
#define MDF_F_BASERATIO             245
#define MDF_F_SOURCEID              246
#define MDF_F_ISSUER                247
#define MDF_F_GENIUMID              248
#define MDF_F_CLOSEPRICE3Y          249
#define MDF_F_CLOSEPRICELD          250
#define MDF_F_FUNDYEARLYMGMTFEE     251
#define MDF_F_FUNDPPMFEE            252
#define MDF_F_FUNDPPMTYPE           253
#define MDF_F_FUNDBENCHMARK         254
#define MDF_F_FUNDLEVERAGE          255
#define MDF_F_FUNDDIRECTION         256
#define MDF_F_PROSPECTUS            257
#define MDF_F_GEOFOCUSREGION        258
#define MDF_F_GEOFOCUSCOUNTRY       259
#define MDF_F_OPENINTEREST          260
#define MDF_F_CLOSEYIELD1D          261
#define MDF_F_CLOSEYIELD1W          262
#define MDF_F_CLOSEYIELD1M          263
#define MDF_F_CLOSEYIELD3M          264
#define MDF_F_CLOSEYIELD6M          265
#define MDF_F_CLOSEYIELD9M          266
#define MDF_F_CLOSEYIELD1Y          267
#define MDF_F_CLOSEYIELD2Y          268
#define MDF_F_CLOSEYIELD3Y          269
#define MDF_F_CLOSEYIELD5Y          270
#define MDF_F_CLOSEYIELD10Y         271
#define MDF_F_CLOSEYIELDWTD         272
#define MDF_F_CLOSEYIELDMTD         273
#define MDF_F_CLOSEYIELDQTD         274
#define MDF_F_CLOSEYIELDYTD         275
#define MDF_F_CLOSEYIELDPYTD        276
#define MDF_F_CLOSEYIELDLD          277
#define MDF_F_ATHYIELD              278
#define MDF_F_ATLYIELD              279
#define MDF_F_ATHYIELDDATE          280
#define MDF_F_ATLYIELDDATE          281
#define MDF_F_HIGHYIELD1Y           282
#define MDF_F_LOWYIELD1Y            283
#define MDF_F_HIGHYIELDYTD          284
#define MDF_F_LOWYIELDYTD           285
#define MDF_F_HIGHYIELDYTDDATE      286
#define MDF_F_LOWYIELDYTDDATE       287
#define MDF_F_HIGHYIELD1YDATE       288
#define MDF_F_LOWYIELD1YDATE        289
#define MDF_F_CUSIP                 290
#define MDF_F_WKN                   291
#define MDF_F_UCITS                 292
#define MDF_F_INCEPTIONDATE         293
#define MDF_F_FUNDBENCHMARKINSREF   294
#define MDF_F_INSTRUMENTCLASS       295
#define MDF_F_INSTRUMENTSUBCLASS    296
#define MDF_F_CONSTITUENTS          297
#define MDF_F_COUPONRATE            298
#define MDF_F_COUPONDATE            299
#define MDF_F_BARRIERPRICE          300
#define MDF_F_STANDARDDEVIATION3Y   301
#define MDF_F_ANNUALIZEDRETURN3Y    302
#define MDF_F_SHARPERATIO3Y         303
#define MDF_F_MORNINGSTARRATING	    304
#define MDF_F_SALESFEE              305
#define MDF_F_PURCHASEFEE           306
#define MDF_F_MINSTARTAMOUNT        307
#define MDF_F_MINSUBSCRIPTIONAMOUNT 308
#define MDF_F_PERFORMANCEFEE        309
#define MDF_F_MINADDITIONALAMOUNT   310
#define MDF_F_ANNUALIZEDRETURN5Y    311
#define MDF_F_ANNUALIZEDRETURN10Y   312
#define MDF_F_CEOADMISSIONDATE      313
#define MDF_F_CHAIRMANADMISSIONDATE 314
#define MDF_F_TRADEDTHROUGHDATE     315
#define MDF_F_TOTALFEE              316
#define MDF_F_DIVIDENDTYPE          317
#define MDF_F_DIVIDENDFREQUENCY     318
#define MDF_F_INSTRUMENTSUBSUBCLASS 319
#define MDF_F_PRIMARYMARKETPLACE    320
#define MDF_F_FISCALPERIOD          321
#define MDF_F_SHORTDESCRIPTION      322
#define MDF_F_FUNDRISK              323
#define MDF_F_EUSIPA                324
#define MDF_F_NEWSRANK              325
#define MDF_F_AVERAGE               326
#define MDF_F_MIN                   327
#define MDF_F_MAX                   328
#define MDF_F_FIELDNAME             329
#define MDF_F_FIELDASPECT           330
#define MDF_F_FIELDTYPE             331
#define MDF_F_FUNDCOMPANY2          332
#define MDF_F_FIELDUNIT             333
#define MDF_F_CLOSEPRICE2W          334
#define MDF_F_CLOSEYIELD2W          335
#define MDF_F_CONVERTFROMDATE       336
#define MDF_F_CONVERTTODATE         337
#define MDF_F_CONVERSIONPRICE       338
#define MDF_F_DURATION              339
#define MDF_F_SETTLEMENTTYPE        340
#define MDF_F_VOTINGPOWER           341
#define MDF_F_CAP                   342
#define MDF_F_IMBALANCE             343
#define MDF_F_IMBALANCEDIRECTION    344
#define MDF_F_CROSSTYPE             345
#define MDF_F_TICKTABLE             346
#define MDF_F_TICKSIZES             347
#define MDF_F_PRICETYPE             348
#define MDF_F_ASIANTAILSTART        349
#define MDF_F_ASIANTAILEND          350
#define MDF_F_LOGOTYPE              351
#define MDF_F_ISSUERNAME            352
#define MDF_F_CONTRACTVALUE         353
#define MDF_F_CLOSEBIDPRICE1D       354
#define MDF_F_CLOSEBIDYIELD1D       355
#define MDF_F_CLOSEBIDPRICE1W       356
#define MDF_F_CLOSEBIDYIELD1W       357
#define MDF_F_FINANCIALINCOME       358
#define MDF_F_FINANCIALCOST         359
#define MDF_F_FINANCINGLEVEL        360
#define MDF_F_PARTICIPATIONRATE     361
#define MDF_F_ISSUEPRICE            362
#define MDF_F_FIINSTITUTENUMBER     363
#define MDF_F_DELETERECORD          364
#define MDF_F_KIID                  365
#define MDF_F_CFI                   366
#define MDF_F_OFFBOOKQUANTITY       367
#define MDF_F_OFFBOOKTURNOVER       368
#define MDF_F_DARKQUANTITY          369
#define MDF_F_DARKTURNOVER          370
#define MDF_F_CLOSEOFFBOOKQUANTITY  371
#define MDF_F_CLOSEOFFBOOKTURNOVER  372
#define MDF_F_CLOSEDARKQUANTITY     373
#define MDF_F_CLOSEDARKTURNOVER     374
#define MDF_F_BROKERS               375
#define MDF_F_INTERESTINCOME        376
#define MDF_F_OTHERFINANCIALINCOME  377
#define MDF_F_INTERESTEXPENSE       378
#define MDF_F_OTHERFINANCIALEXPENSE 379
#define MDF_F_MINORITYINTERESTRES   380
#define MDF_F_ACCOUNTSPAYABLE       381
#define MDF_F_EVENTLINK             382
#define MDF_F_EVENTLINKLANGUAGES    383
#define MDF_F_MAXLEVEL              384
#define MDF_F_SETTLEMENTPRICE       385
#define MDF_F_ANNUALIZEDRETURN1Y    386
#define MDF_F_ANNUALIZEDRETURN2Y    387
#define MDF_F_ANNUALIZEDRETURN4Y    388
#define MDF_F_S6                    389
#define MDF_F_S7                    390
#define MDF_F_S8                    391
#define MDF_F_S9                    392
#define MDF_F_S10                   393
#define MDF_F_N1                    394
#define MDF_F_N2                    395
#define MDF_F_N3                    396
#define MDF_F_N4                    397
#define MDF_F_N5                    398
#define MDF_F_I1                    399
#define MDF_F_I2                    400
#define MDF_F_I3                    401
#define MDF_F_I4                    402
#define MDF_F_I5                    403
#define MDF_F_D1                    404
#define MDF_F_D2                    405
#define MDF_F_D3                    406
#define MDF_F_CITYPE                407
#define MDF_F_CISUBTYPE             408
#define MDF_F_SEQUENCE              409
#define MDF_F_OUTSTANDINGAMOUNT     410
#define MDF_F_INTERESTRATE          411
#define MDF_F_MARKETMAKER           412
#define MDF_F_SUSTAINDESCRIPTION    413
#define MDF_F_SUSTAININVESTING1     414
#define MDF_F_SUSTAININVESTING2     415
#define MDF_F_SUSTAINDIVESTING1     416
#define MDF_F_SUSTAINDIVESTING2     417
#define MDF_F_SUSTAININFLUENCE      418
#define MDF_F_SUSTAINMONITORING1    419
#define MDF_F_SUSTAINMONITORING2    420
#define MDF_F_SUSTAINCOMMENT        421
#define MDF_F_NUMBEROFPREFSHARES    422
#define MDF_F_MARKETOPEN            423
#define MDF_F_MARKETCLOSE           424
#define MDF_F_MARKETEARLYCLOSE      425
#define MDF_F_LEGALSTRUCTURE        426
#define MDF_F_ONGOINGCHARGE         427
#define MDF_F_PRICINGFREQUENCY      428
#define MDF_F_MARKETOPENDAYS        429
#define MDF_F_CLOSETRADEPRICE       430
#define MDF_F_CLOSEPRICETYPE        431
#define MDF_F_NETDIVIDEND           432
#define MDF_F_PRODUCTCODE           433
#define MDF_F_QUOTINGTYPE           434
#define MDF_F_TRADEAGREEMENTTIME    435
#define MDF_F_TRADEAGREEMENTDATE    436
#define MDF_F_LATESTYEARENDREPORT   437
#define MDF_F_VOLUMEDIMENSION       438
#define MDF_F_NEWSCODINGREGULATORY  439
#define MDF_F_NORMANAMOUNT          440
#define MDF_F_CSR                   441
#define MDF_F_S11                   442
#define MDF_F_CIK                   443
#define MDF_F_PRIIP00010            444
#define MDF_F_PRIIP00020            445
#define MDF_F_PRIIP00030            446
#define MDF_F_PRIIP00040            447
#define MDF_F_PRIIP00050            448
#define MDF_F_PRIIP00060            449
#define MDF_F_PRIIPKID              450
#define MDF_F_PRIIP00080            451
#define MDF_F_PRIIP00090            452
#define MDF_F_PRIIP00100            453
#define MDF_F_PRIIP01010            454
#define MDF_F_PRIIP01020            455
#define MDF_F_PRIIP01030            456
#define MDF_F_PRIIP01040            457
#define MDF_F_PRIIP01050            458
#define MDF_F_PRIIP01060            459
#define MDF_F_PRIIP01070            460
#define MDF_F_PRIIP01080            461
#define MDF_F_PRIIP01090            462
#define MDF_F_PRIIP01100            463
#define MDF_F_PRIIP01110            464
#define MDF_F_PRIIP01120            465
/* #define MDF_F_PRIIP01130            466 */
#define MDF_F_PRIIP01140            467
#define MDF_F_PRIIP02010            468
#define MDF_F_PRIIP02020            469
#define MDF_F_PRIIP02030            470
#define MDF_F_PRIIP02040            471
#define MDF_F_PRIIP02050            472
#define MDF_F_PRIIP02060            473
#define MDF_F_PRIIP02070            474
#define MDF_F_PRIIP02080            475
#define MDF_F_PRIIP02090            476
#define MDF_F_PRIIP02100            477
#define MDF_F_PRIIP02110            478
#define MDF_F_PRIIP02120            479
#define MDF_F_PRIIP02130            480
#define MDF_F_PRIIP02140            481
#define MDF_F_PRIIP02150            482
#define MDF_F_PRIIP02160            483
#define MDF_F_PRIIP02170            484
#define MDF_F_PRIIP02180            485
#define MDF_F_PRIIP03010            486
#define MDF_F_PRIIP03015            487
#define MDF_F_PRIIP03020            488
#define MDF_F_PRIIP03030            489
#define MDF_F_PRIIP03040            490
#define MDF_F_PRIIP03050            491
#define MDF_F_PRIIP03060            492
#define MDF_F_PRIIP03070            493
#define MDF_F_PRIIP03080            494
#define MDF_F_PRIIP03090            495
#define MDF_F_PRIIP03095            496
#define MDF_F_PRIIP03100            497
#define MDF_F_PRIIP03105            498
#define MDF_F_SUBMARKET             499
#define MDF_F_PRIIP04020            500
#define MDF_F_PRIIP04030            501
#define MDF_F_PRIIP04040            502
#define MDF_F_PRIIP04050            503
#define MDF_F_PRIIP04060            504
#define MDF_F_PRIIP04070            505
#define MDF_F_PRIIP04080            506
#define MDF_F_PRIIP04081            507
#define MDF_F_PRIIP04082            508
#define MDF_F_PRIIP04083            509
#define MDF_F_PRIIP04084            510
#define MDF_F_PRIIP04085            511
#define MDF_F_PRIIP04090            512
#define MDF_F_PRIIP04100            513
#define MDF_F_PRIIP04110            514
#define MDF_F_PRIIP05010            515
#define MDF_F_PRIIP05020            516
#define MDF_F_PRIIP05030            517
#define MDF_F_PRIIP05040            518
#define MDF_F_PRIIP05050            519
#define MDF_F_PRIIP05060            520
#define MDF_F_PRIIP05065            521
#define MDF_F_PRIIP05070            522
#define MDF_F_PRIIP05080            523
#define MDF_F_MMT                   524
#define MDF_F_FISN                  525
#define MDF_F_LEI                   526
#define MDF_F_SECTORMEMBERS         527
#define MDF_F_PRIIP06010            528
#define MDF_F_PRIIP06020            529
#define MDF_F_PRIIP06030            530
#define MDF_F_PRIIP06040            531
#define MDF_F_PRIIP06050            532
#define MDF_F_PRIIP06060            533
#define MDF_F_PRIIP06070            534
#define MDF_F_PRIIP06080            535
#define MDF_F_PRIIP07010            536
#define MDF_F_PRIIP07020            537
#define MDF_F_PRIIP07030            538
#define MDF_F_PRIIP07040            539
#define MDF_F_PRIIP07050            540
#define MDF_F_PRIIP07060            541
#define MDF_F_PRIIP07070            542
#define MDF_F_PRIIP07080            543
#define MDF_F_PRIIP07090            544
#define MDF_F_PRIIP07100            545
#define MDF_F_PRIIP07110            546
#define MDF_F_PRIIP07120            547
#define MDF_F_MIFID00010            548
#define MDF_F_MIFID00020            549
#define MDF_F_MIFID00030            550
#define MDF_F_MIFID00040            551
#define MDF_F_NEWSIDREPLACE         552
#define MDF_F_MIFID00060            553
#define MDF_F_MIFID00070            554
#define MDF_F_MIFID00080            555
#define MDF_F_MIFID00090            556
#define MDF_F_MIFID00100            557
#define MDF_F_MIFID01010            558
#define MDF_F_MIFID01020            559
#define MDF_F_MIFID01030            560
#define MDF_F_MIFID02010            561
#define MDF_F_MIFID02020            562
#define MDF_F_MIFID02030            563
#define MDF_F_MIFID02040            564
#define MDF_F_MIFID03010            565
#define MDF_F_MIFID03020            566
#define MDF_F_MIFID03030            567
#define MDF_F_MIFID03040            568
#define MDF_F_MIFID03050            569
#define MDF_F_MIFID04010            570
#define MDF_F_MIFID04020            571
#define MDF_F_MIFID04030            572
#define MDF_F_MIFID04040            573
#define MDF_F_MIFID04050            574
#define MDF_F_MIFID05010            575
#define MDF_F_MIFID05020            576
#define MDF_F_MIFID05030            577
#define MDF_F_MIFID05040            578
#define MDF_F_MIFID05050            579
#define MDF_F_MIFID05060            580
#define MDF_F_MIFID05070            581
#define MDF_F_MIFID05080            582
#define MDF_F_MIFID05080N           583
#define MDF_F_ENTITLEMENTPACKAGE    584
#define MDF_F_MIFID05100            585
#define MDF_F_MIFID05110            586
#define MDF_F_MIFID06010            587
#define MDF_F_MIFID06020            588
#define MDF_F_MIFID06030            589
#define MDF_F_MIFID06040            590
#define MDF_F_MIFID07010            591
#define MDF_F_MIFID07020            592
#define MDF_F_MIFID07030            593
#define MDF_F_MIFID07040            594
#define MDF_F_MIFID07050            595
#define MDF_F_MIFID07060            596
#define MDF_F_MIFID07070            597
#define MDF_F_MIFID07080            598
#define MDF_F_MIFID07090            599
#define MDF_F_MIFID07100            600
#define MDF_F_MIFID07110            601
#define MDF_F_MIFID07120            602
#define MDF_F_MIFID07130            603
#define MDF_F_MIFID07140            604
#define MDF_F_MIFID08010            605
#define MDF_F_MIFID08020            606
#define MDF_F_MIFID08030            607
#define MDF_F_MIFID08040            608
#define MDF_F_MIFID08050            609
#define MDF_F_MIFID08060            610
#define MDF_F_MIFID08070            611
#define MDF_F_MIFID08080            612
#define MDF_F_MIFID08090            613
#define MDF_F_MIFID08100            614
#define MDF_F_OPERATINGMIC          615
#define MDF_F_CVR                   616
#define MDF_F_KENNITALA             617
#define MDF_F_YTUNNUS               618
#define MDF_F_ORGNUMNO              619
#define MDF_F_NEWSCODINGTAGS        620
#define MDF_F_NEWSCODINGIMPACT      621
#define MDF_F_ACTIVESHARE           622
#define MDF_F_TRACKINGERROR         623
#define MDF_F_HIGHPRICE3Y           624
#define MDF_F_LOWPRICE3Y            625
#define MDF_F_HIGHPRICE5Y           626
#define MDF_F_LOWPRICE5Y            627
#define MDF_F_HIGHPRICE10Y          628
#define MDF_F_LOWPRICE10Y           629
#define MDF_F_DPS                   630
#define MDF_F_CFPS                  631
#define MDF_F_CFPSTTM               632
#define MDF_F_CFPSLAST              633
#define MDF_F_EPSTTM                634
#define MDF_F_EPSLAST               635
#define MDF_F_SPS                   636
#define MDF_F_SPSTTM                637
#define MDF_F_SPSLAST               638
#define MDF_F_BVPS                  639
#define MDF_F_BVPSLAST              640
#define MDF_F_ROE                   641
#define MDF_F_ROETTM                642
#define MDF_F_ROELAST               643
#define MDF_F_ROA                   644
#define MDF_F_ROATTM                645
#define MDF_F_ROALAST               646
#define MDF_F_GM                    647
#define MDF_F_GMTTM                 648
#define MDF_F_GMLAST                649
#define MDF_F_OM                    650
#define MDF_F_OMTTM                 651
#define MDF_F_OMLAST                652
#define MDF_F_PM                    653
#define MDF_F_PMTTM                 654
#define MDF_F_PMLAST                655
#define MDF_F_MIFID00001            656
#define MDF_F_MIFID00005            657
#define MDF_F_MIFID00006            658
#define MDF_F_MIFID00007            659
#define MDF_F_MIFID00008            660
#define MDF_F_MIFID00045            661
#define MDF_F_MIFID00047            662
#define MDF_F_MIFID00002            663
#define MDF_F_MIFID00003            664
#define MDF_F_MIFID00073            665
#define MDF_F_MIFID00074            666
#define MDF_F_MIFID00075            667
#define MDF_F_MIFID00085            668
#define MDF_F_MIFID00095            669
#define MDF_F_MIFID00110            670
#define MDF_F_MIFID00120            671
#define MDF_F_MIFID00004            672
#define MDF_F_MIFID01000            673
#define MDF_F_MIFID05105            674
#define MDF_F_MIFID05115            675
#define MDF_F_MIFID07025            676
/* #define MDF_F_MIFID07101            677 */
#define MDF_F_MIFID07105            678
#define MDF_F_MIFID07150            679
#define MDF_F_MIFID07155            680
#define MDF_F_MIFID07160            681
#define MDF_F_MIFID08015            682
#define MDF_F_MIFID08025            683
#define MDF_F_MIFID08045            684
/* #define MDF_F_MIFID08046            685 */
/* #define MDF_F_MIFID08085            686 */
#define MDF_F_MIFID08110            687
#define MDF_F_MIFID08120            688
#define MDF_F_FIGI                  689
#define MDF_F_FIGICOMPOSITE         690
#define MDF_F_FIGISHARECLASS        691
#define MDF_F_MMO                   692
#define MDF_F_FIGISECURITYTYPE      693
#define MDF_F_COUPONFREQUENCY       694
#define MDF_F_ORDERID               695
#define MDF_F_ORDERIDSOURCE         696
#define MDF_F_ORDERPRIORITY         697
#define MDF_F_IV                    698
#define MDF_F_DELTA                 699
#define MDF_F_GAMMA                 700
#define MDF_F_RHO                   701
#define MDF_F_THETA                 702
#define MDF_F_VEGA                  703
#define MDF_F_ORDERSIDE             704
#define MDF_F_ORDERPARTICIPANT      705
#define MDF_F_ORDERPRICE            706
#define MDF_F_ORDERQUANTITY         707
#define MDF_F_IVBID                 708
#define MDF_F_IVASK                 709
#define MDF_F_DAYCOUNTCONVENTION    710
#define MDF_F_EXPIRATIONTYPE        711
#define MDF_F_TENOR                 712
#define MDF_F_S12                   713
#define MDF_F_S13                   714
#define MDF_F_S14                   715
#define MDF_F_S15                   716
#define MDF_F_N6                    717
#define MDF_F_N7                    718
#define MDF_F_N8                    719
#define MDF_F_N9                    720
#define MDF_F_N10                   721
#define MDF_F_I6                    722
#define MDF_F_I7                    723
#define MDF_F_I8                    724
#define MDF_F_I9                    725
#define MDF_F_I10                   726
#define MDF_F_INSREF1               727
#define MDF_F_INSREF2               728
#define MDF_F_INSREF3               729
#define MDF_F_INSREF4               730
#define MDF_F_INSREF5               731
#define MDF_F_COMBOLEGS             732
#define MDF_F_SWINGFACTOR           733
#define MDF_F_SWINGMETHOD           734
#define MDF_F_INCOMEPROPMAN         735

#endif
